Class: Google::Apis::FcmV1::ApnsConfig
- Inherits:
-
Object
- Object
- Google::Apis::FcmV1::ApnsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/fcm_v1/classes.rb,
lib/google/apis/fcm_v1/representations.rb,
lib/google/apis/fcm_v1/representations.rb
Overview
Apple Push Notification Service specific options.
Instance Attribute Summary collapse
-
#fcm_options ⇒ Google::Apis::FcmV1::ApnsFcmOptions
Options for features provided by the FCM SDK for iOS.
-
#headers ⇒ Hash<String,String>
HTTP request headers defined in Apple Push Notification Service.
-
#live_activity_token ⇒ String
Optional.
-
#payload ⇒ Hash<String,Object>
APNs payload as a JSON object, including both
apsdictionary and custom payload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApnsConfig
constructor
A new instance of ApnsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApnsConfig
Returns a new instance of ApnsConfig.
446 447 448 |
# File 'lib/google/apis/fcm_v1/classes.rb', line 446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fcm_options ⇒ Google::Apis::FcmV1::ApnsFcmOptions
Options for features provided by the FCM SDK for iOS.
Corresponds to the JSON property fcmOptions
410 411 412 |
# File 'lib/google/apis/fcm_v1/classes.rb', line 410 def @fcm_options end |
#headers ⇒ Hash<String,String>
HTTP request headers defined in Apple Push Notification Service. Refer to
APNs request headers for supported headers such as apns-
expiration and apns-priority. The backend sets a default value for apns-
expiration of 30 days and a default value for apns-priority of 10 if not
explicitly set.
Corresponds to the JSON property headers
421 422 423 |
# File 'lib/google/apis/fcm_v1/classes.rb', line 421 def headers @headers end |
#live_activity_token ⇒ String
Optional. Apple Live Activity token to send updates to. This token can
either be a push token or push-to-start token from Apple. To
start, update, or end a live activity remotely using FCM, construct an aps
payload and put it in the apns.payload
field.
Corresponds to the JSON property liveActivityToken
435 436 437 |
# File 'lib/google/apis/fcm_v1/classes.rb', line 435 def live_activity_token @live_activity_token end |
#payload ⇒ Hash<String,Object>
APNs payload as a JSON object, including both aps dictionary and custom
payload. See Payload Key Reference. If present, it overrides google.firebase.
fcm.v1.Notification.title and google.firebase.fcm.v1.Notification.body.
Corresponds to the JSON property payload
444 445 446 |
# File 'lib/google/apis/fcm_v1/classes.rb', line 444 def payload @payload end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
451 452 453 454 455 456 |
# File 'lib/google/apis/fcm_v1/classes.rb', line 451 def update!(**args) @fcm_options = args[:fcm_options] if args.key?(:fcm_options) @headers = args[:headers] if args.key?(:headers) @live_activity_token = args[:live_activity_token] if args.key?(:live_activity_token) @payload = args[:payload] if args.key?(:payload) end |